Stan Math Library: stan/math/prim/scal/fun/inv_square.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_square.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INV_SQUARE_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INV_SQUARE_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5
6 namespace stan {
7 namespace math {
8
9 template <typename T>
10 inline
11 typename boost::math::tools::promote_args<T>::type
12 inv_square(const T x) {
13 return 1.0 / (x * x);
14 }
15 }
16 }
17
18 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::inv_square
fvar< T > inv_square(const fvar< T > &x)
Definition: inv_square.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.